@@ -128,7 +128,6 @@ impl Handler for CircuitDirectMessageHandler {
                                     .get_peer_auth_token(circuit.authorization_type())
                                     .map_err(|err| DispatchError::HandleError(err.to_string()))?;
 
-                                #[cfg(feature = "challenge-authorization")]
                                 let local_peer_id = self
                                     .routing_table
                                     .get_node(&self.node_id)
@@ -142,11 +141,7 @@ impl Handler for CircuitDirectMessageHandler {
                                     .get_peer_auth_token(circuit.authorization_type())
                                     .map_err(|err| DispatchError::HandleError(err.to_string()))?;
 
-                                PeerTokenPair::new(
-                                    peer_id,
-                                    #[cfg(feature = "challenge-authorization")]
-                                    local_peer_id,
-                                )
+                                PeerTokenPair::new(peer_id, local_peer_id)
                             }
                             .into();
 
@@ -243,7 +238,6 @@ mod tests {
     use std::collections::VecDeque;
     use std::sync::{Arc, Mutex};
 
-    #[cfg(feature = "challenge-authorization")]
     use crate::circuit::routing::AuthorizationType;
     use crate::circuit::routing::{
         memory::RoutingTable, Circuit, CircuitNode, RoutingTableWriter, Service,
@@ -265,18 +259,8 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_123 = CircuitNode::new(
-            "123".to_string(),
-            vec!["123.0.0.1:0".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
-        let node_345 = CircuitNode::new(
-            "345".to_string(),
-            vec!["123.0.0.1:1".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
+        let node_123 = CircuitNode::new("123".to_string(), vec!["123.0.0.1:0".to_string()], None);
+        let node_345 = CircuitNode::new("345".to_string(), vec!["123.0.0.1:1".to_string()], None);
 
         let mut service_abc = Service::new(
             "abc".to_string(),
@@ -293,12 +277,10 @@ mod tests {
 
         service_abc.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("abc_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("123"),
         ));
         service_def.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("def_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("345"),
         ));
 
@@ -307,7 +289,6 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
-            #[cfg(feature = "challenge-authorization")]
             AuthorizationType::Trust,
         );
 
@@ -337,7 +318,6 @@ mod tests {
             .dispatch(
                 PeerTokenPair::new(
                     PeerAuthorizationToken::from_peer_id("def"),
-                    #[cfg(feature = "challenge-authorization")]
                     PeerAuthorizationToken::from_peer_id("345"),
                 )
                 .into(),
@@ -352,7 +332,6 @@ mod tests {
             id.into(),
             PeerTokenPair::new(
                 PeerAuthorizationToken::from_peer_id("abc_network"),
-                #[cfg(feature = "challenge-authorization")]
                 PeerAuthorizationToken::from_peer_id("123"),
             ),
             CircuitMessageType::CIRCUIT_DIRECT_MESSAGE,
@@ -378,18 +357,8 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_123 = CircuitNode::new(
-            "123".to_string(),
-            vec!["123.0.0.1:0".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
-        let node_345 = CircuitNode::new(
-            "345".to_string(),
-            vec!["123.0.0.1:1".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
+        let node_123 = CircuitNode::new("123".to_string(), vec!["123.0.0.1:0".to_string()], None);
+        let node_345 = CircuitNode::new("345".to_string(), vec!["123.0.0.1:1".to_string()], None);
 
         let mut service_abc = Service::new(
             "abc".to_string(),
@@ -406,12 +375,10 @@ mod tests {
 
         service_abc.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("abc_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("123"),
         ));
         service_def.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("def_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("345"),
         ));
 
@@ -420,7 +387,6 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
-            #[cfg(feature = "challenge-authorization")]
             AuthorizationType::Trust,
         );
 
@@ -451,7 +417,6 @@ mod tests {
             .dispatch(
                 PeerTokenPair::new(
                     PeerAuthorizationToken::from_peer_id("def"),
-                    #[cfg(feature = "challenge-authorization")]
                     PeerAuthorizationToken::from_peer_id("345"),
                 )
                 .into(),
@@ -466,7 +431,6 @@ mod tests {
             id.into(),
             PeerTokenPair::new(
                 PeerAuthorizationToken::from_peer_id("123"),
-                #[cfg(feature = "challenge-authorization")]
                 PeerAuthorizationToken::from_peer_id("345"),
             ),
             CircuitMessageType::CIRCUIT_DIRECT_MESSAGE,
@@ -491,18 +455,8 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_123 = CircuitNode::new(
-            "123".to_string(),
-            vec!["123.0.0.1:0".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
-        let node_345 = CircuitNode::new(
-            "345".to_string(),
-            vec!["123.0.0.1:1".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
+        let node_123 = CircuitNode::new("123".to_string(), vec!["123.0.0.1:0".to_string()], None);
+        let node_345 = CircuitNode::new("345".to_string(), vec!["123.0.0.1:1".to_string()], None);
 
         let mut service_abc = Service::new(
             "abc".to_string(),
@@ -513,7 +467,6 @@ mod tests {
 
         service_abc.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("abc_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("123"),
         ));
 
@@ -522,7 +475,6 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone()],
             vec!["123".into(), "345".into()],
-            #[cfg(feature = "challenge-authorization")]
             AuthorizationType::Trust,
         );
 
@@ -553,7 +505,6 @@ mod tests {
             .dispatch(
                 PeerTokenPair::new(
                     PeerAuthorizationToken::from_peer_id("def"),
-                    #[cfg(feature = "challenge-authorization")]
                     PeerAuthorizationToken::from_peer_id("345"),
                 )
                 .into(),
@@ -568,7 +519,6 @@ mod tests {
             id.into(),
             PeerTokenPair::new(
                 PeerAuthorizationToken::from_peer_id("def"),
-                #[cfg(feature = "challenge-authorization")]
                 PeerAuthorizationToken::from_peer_id("345"),
             ),
             CircuitMessageType::CIRCUIT_ERROR_MESSAGE,
@@ -594,18 +544,8 @@ mod tests {
         let reader: Box<dyn RoutingTableReader> = Box::new(table.clone());
         let mut writer: Box<dyn RoutingTableWriter> = Box::new(table.clone());
 
-        let node_123 = CircuitNode::new(
-            "123".to_string(),
-            vec!["123.0.0.1:0".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
-        let node_345 = CircuitNode::new(
-            "345".to_string(),
-            vec!["123.0.0.1:1".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
+        let node_123 = CircuitNode::new("123".to_string(), vec!["123.0.0.1:0".to_string()], None);
+        let node_345 = CircuitNode::new("345".to_string(), vec!["123.0.0.1:1".to_string()], None);
 
         let mut service_def = Service::new(
             "def".to_string(),
@@ -616,7 +556,6 @@ mod tests {
 
         service_def.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("def_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("345"),
         ));
 
@@ -625,7 +564,6 @@ mod tests {
             "alpha".into(),
             vec![service_def.clone()],
             vec!["123".into(), "345".into()],
-            #[cfg(feature = "challenge-authorization")]
             AuthorizationType::Trust,
         );
 
@@ -655,7 +593,6 @@ mod tests {
             .dispatch(
                 PeerTokenPair::new(
                     PeerAuthorizationToken::from_peer_id("def"),
-                    #[cfg(feature = "challenge-authorization")]
                     PeerAuthorizationToken::from_peer_id("345"),
                 )
                 .into(),
@@ -670,7 +607,6 @@ mod tests {
             id.into(),
             PeerTokenPair::new(
                 PeerAuthorizationToken::from_peer_id("def"),
-                #[cfg(feature = "challenge-authorization")]
                 PeerAuthorizationToken::from_peer_id("345"),
             ),
             CircuitMessageType::CIRCUIT_ERROR_MESSAGE,
@@ -713,7 +649,6 @@ mod tests {
             .dispatch(
                 PeerTokenPair::new(
                     PeerAuthorizationToken::from_peer_id("def"),
-                    #[cfg(feature = "challenge-authorization")]
                     PeerAuthorizationToken::from_peer_id("345"),
                 )
                 .into(),
@@ -728,7 +663,6 @@ mod tests {
             id.into(),
             PeerTokenPair::new(
                 PeerAuthorizationToken::from_peer_id("def"),
-                #[cfg(feature = "challenge-authorization")]
                 PeerAuthorizationToken::from_peer_id("345"),
             ),
             CircuitMessageType::CIRCUIT_ERROR_MESSAGE,
