@@ -86,8 +86,8 @@ impl Error for RequestError {}
 impl fmt::Display for RequestError {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
-            RequestError::MissingHeader(msg) => f.write_str(&msg),
-            RequestError::InvalidHeaderValue(msg) => f.write_str(&msg),
+            RequestError::MissingHeader(msg) => f.write_str(msg),
+            RequestError::InvalidHeaderValue(msg) => f.write_str(msg),
         }
     }
 }
