@@ -738,12 +738,8 @@ pub mod tests {
             callback: Box<
                 dyn Fn(AuthorizationResult) -> Result<(), Box<dyn std::error::Error>> + Send,
             >,
-            #[cfg(feature = "challenge-authorization")] _expected_authorization: Option<
-                ConnectionAuthorizationType,
-            >,
-            #[cfg(feature = "challenge-authorization")] _local_authorization: Option<
-                ConnectionAuthorizationType,
-            >,
+            _expected_authorization: Option<ConnectionAuthorizationType>,
+            _local_authorization: Option<ConnectionAuthorizationType>,
         ) -> Result<(), AuthorizerError> {
             (*callback)(AuthorizationResult::Authorized {
                 connection_id,
@@ -751,11 +747,9 @@ pub mod tests {
                 identity: ConnectionAuthorizationType::Trust {
                     identity: self.authorized_id.clone(),
                 },
-                #[cfg(feature = "challenge-authorization")]
                 expected_authorization: ConnectionAuthorizationType::Trust {
                     identity: self.authorized_id.clone(),
                 },
-                #[cfg(feature = "challenge-authorization")]
                 local_authorization: ConnectionAuthorizationType::Trust {
                     identity: "local_id".into(),
                 },
