@@ -20,8 +20,63 @@ use diesel::{
     sqlite::SqliteConnection,
 };
 
+use crate::error::InternalError;
+use crate::migrations::{any_pending_sqlite_migrations, run_sqlite_migrations};
+
 use super::StoreFactory;
 
+/// Create a SQLite connection pool.
+///
+/// # Arguments
+///
+/// * conn_str - a filename or ":memory:"
+///
+/// # Errors
+///
+/// An [InternalError] is returned if
+/// * The file does not exist
+/// * The pool cannot be created
+/// * The database requires any pending migrations
+pub fn create_sqlite_connection_pool(
+    conn_str: &str,
+) -> Result<Pool<ConnectionManager<SqliteConnection>>, InternalError> {
+    if (conn_str != ":memory:") && !std::path::Path::new(&conn_str).exists() {
+        return Err(InternalError::with_message(format!(
+            "Database file '{}' does not exist",
+            conn_str
+        )));
+    }
+    let connection_manager = ConnectionManager::<SqliteConnection>::new(conn_str);
+    let mut pool_builder =
+        Pool::builder().connection_customizer(Box::new(ConnectionCustomizer::default()));
+    // A new database is created for each connection to the in-memory SQLite
+    // implementation; to ensure that the resulting stores will operate on the same
+    // database, only one connection is allowed.
+    if conn_str == ":memory:" {
+        pool_builder = pool_builder.max_size(1);
+    }
+    let pool = pool_builder.build(connection_manager).map_err(|err| {
+        InternalError::from_source_with_prefix(
+            Box::new(err),
+            "Failed to build connection pool".to_string(),
+        )
+    })?;
+    let conn = pool
+        .get()
+        .map_err(|err| InternalError::from_source(Box::new(err)))?;
+    if conn_str == ":memory:" {
+        run_sqlite_migrations(&conn)?;
+    } else if !any_pending_sqlite_migrations(&conn)? {
+        return Err(InternalError::with_message(String::from(
+            "This version of splinter requires migrations that are not yet applied \
+            to the database. Run `splinter database migrate` to apply migrations \
+            before running splinterd",
+        )));
+    }
+
+    Ok(pool)
+}
+
 /// A `StoreFactory` backed by a SQLite database.
 pub struct SqliteStoreFactory {
     pool: Pool<ConnectionManager<SqliteConnection>>,
@@ -108,11 +163,19 @@ impl StoreFactory for SqliteStoreFactory {
 #[derive(Default, Debug)]
 /// Foreign keys must be enabled on a per connection basis. This customizer will be added to the
 /// SQLite pool builder and then ran against every connection returned from the pool.
-pub struct ForeignKeyCustomizer;
+pub struct ConnectionCustomizer;
 
-impl CustomizeConnection<SqliteConnection, diesel::r2d2::Error> for ForeignKeyCustomizer {
+impl CustomizeConnection<SqliteConnection, diesel::r2d2::Error> for ConnectionCustomizer {
     fn on_acquire(&self, conn: &mut SqliteConnection) -> Result<(), diesel::r2d2::Error> {
-        conn.batch_execute("PRAGMA foreign_keys = ON;")
-            .map_err(diesel::r2d2::Error::QueryError)
+        conn.batch_execute(
+            r#"
+            PRAGMA busy_timeout = 2000;
+            PRAGMA journal_mode = WAL;
+            PRAGMA wal_checkpoint(truncate);
+            PRAGMA synchronous = FULL;
+            PRAGMA foreign_keys = ON;
+            "#,
+        )
+        .map_err(diesel::r2d2::Error::QueryError)
     }
 }
